import Foundation

/// The ParsingError codes generated by JSON.
enum ParsingError: ErrorProtocol {
    case notFound, failed
}

class JSON {
    /**
    Returns a JSON object from a file.
    - parameter fileName: The name of the file, the expected extension is `.json`.
    - parameter bundle:  The Bundle where the file is located, by default is the main bundle.
    - returns: A JSON object, it can be either a Dictionary or an Array.
    */
    class func from(_ fileName: String, bundle: Bundle = Bundle.main()) throws -> AnyObject? {
        var JSON: AnyObject?

        guard let url = URL(string: fileName), filePath = bundle.pathForResource(try! url.deletingPathExtension().absoluteString, ofType: url.pathExtension) else { throw ParsingError.notFound }

        guard let data = try? Data(contentsOf: URL(fileURLWithPath: filePath)) else { throw ParsingError.failed }

        JSON = try data.toJSON()

        return JSON
    }
}

extension Data {
    /**
    Converts Data to a JSON object.
    - returns: A JSON object, it can be either a Dictionary or an Array.
    */
    func toJSON() throws -> AnyObject? {
        var JSON: AnyObject?
        do {
            JSON = try JSONSerialization.jsonObject(with: self, options: [])
        } catch {
            throw ParsingError.failed
        }
        
        return JSON
    }
}
